package com.gic.haoban.manage.service.service.out.impl.content.task;

import cn.hutool.core.date.DateTime;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.haoban.manage.api.service.content.task.CommissionTaskApiService;
import com.gic.haoban.manage.service.pojo.bo.commission.ClerkCommissionStaticsBO;
import com.gic.haoban.manage.service.service.commission.CommissionNotifyInnerService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * @Author MUSI
 * @Date 2023/6/7 2:16 PM
 * @Description
 * @Version
 **/
@Component("commissionTaskApiService")
public class CommissionTaskApiServiceImpl implements CommissionTaskApiService {

    @Autowired
    private CommissionNotifyInnerService commissionNotifyInnerService;

    private static final Logger log = LoggerFactory.getLogger(CommissionTaskApiService.class);

    /**
     * 判断是否是当天第一次
     * 执行时间处于 8:00 ~ 8:30
     *
     * @param now
     * @return
     */
    int hour_sec = 30 * 60;

    private boolean checkIsTodayFirst(Date now) {
        DateTime temp = cn.hutool.core.date.DateUtil.offsetSecond(now, -(hour_sec));
        return cn.hutool.core.date.DateUtil.hour(temp, true) < 8;
    }

    /**
     * 处理佣金消息通知
     *
     * @param prams
     */
    @Override
    public ServiceResponse<Void> handlerCommissionNotify(String prams) {

        Date now = new Date();
        log.info("handlerCommissionNotify 执行佣金统计通知 {}", cn.hutool.core.date.DateUtil.format(now, "yyyy-MM-dd HH:mm:ss"));
        int currentHour = cn.hutool.core.date.DateUtil.hour(now, true);
        if (currentHour >= 23 || currentHour < 8) {
            log.info("当前时间处于消息禁发时间, 忽略{}", cn.hutool.core.date.DateUtil.format(now, "yyyy-MM-dd HH:mm:ss"));
            return ServiceResponse.success();
        }
        Date startTime = cn.hutool.core.date.DateUtil.offsetMinute(now, -30).toJdkDate();
        // 如果是8点那次的执行 需要获取 23 ～ 8点的数据
        if (checkIsTodayFirst(now)) {
            log.info("本次执行为当天第一次执行 {}", cn.hutool.core.date.DateUtil.format(now, "yyyy-MM-dd HH:mm:ss"));
            Date yesterday = cn.hutool.core.date.DateUtil.yesterday().toJdkDate();
            Calendar calendar = Calendar.getInstance();
            calendar.clear();
            calendar.setTime(yesterday);
            calendar.set(Calendar.HOUR_OF_DAY, 23);
            calendar.set(Calendar.MINUTE, 0);
            calendar.set(Calendar.SECOND, 0);
            calendar.set(Calendar.MILLISECOND, 0);
            startTime = calendar.getTime();
        }

        // enterpriseId, clerkId, memberNum, commissionAmount
        List<ClerkCommissionStaticsBO> needHandlerClerkInfos = new ArrayList<>();

        needHandlerClerkInfos.add(buildDemo());

        if (CollectionUtils.isEmpty(needHandlerClerkInfos)) {
            return ServiceResponse.success();
        }
        for (ClerkCommissionStaticsBO clerkCommissionStaticsBO : needHandlerClerkInfos) {
            commissionNotifyInnerService.handlerCommissionNotify(clerkCommissionStaticsBO);
        }
        return ServiceResponse.success();
    }

    private ClerkCommissionStaticsBO buildDemo() {
        ClerkCommissionStaticsBO clerkCommissionStatics = new ClerkCommissionStaticsBO();
        clerkCommissionStatics.setEnterpriseId("ff8080815dacd3a2015dacd3ef5c0000");
        clerkCommissionStatics.setClerkId("279871592fcd49659ad5f348039dba3f");
        clerkCommissionStatics.setNum(10);
        clerkCommissionStatics.setCommissionAmount(BigDecimal.valueOf(10000));
        return clerkCommissionStatics;
    }
}
